@@ -22,15 +22,12 @@ class MyLLM:
     with a given model and a given provider
 
     Attributes:
-        logger (Logger): Logger
         enabled (bool): Whether MyLLM is enabled
-        commands (str): MyLLM commands
         llm (LLM): LLM
         conversation (ConversationChain): Conversation
 
     Methods:
         get_myllm_info(self)
-        get_myllm_help(self)
         chat(self, prompt)
         clear_chat_history(self)
 
@@ -52,7 +49,8 @@ class MyLLM:
         provider_module = importlib.import_module(provider_module_name)
         provider_class = getattr(provider_module, provider_module_name.split(".")[-1])
         self.provider = provider_class()
-        self.llm_model = settings.llm_model
+        self.model = settings.llm_model
+        self.lag = settings.lag
         self.conversation = Conversation()
 
     async def get_myllm_info(self):
@@ -62,9 +60,7 @@ class MyLLM:
         Returns:
             str: A string containing the MyLLM version, model, and provider.
         """
-        return (
-            f"ℹ️ MyLLM v{__version__}\n {settings.llm_model}\n{settings.llm_provider}"
-        )
+        return f"ℹ️ MyLLM v{__version__}\n {self.model}\n{self.provider}"
 
     async def chat(self, prompt):
         """
@@ -79,14 +75,15 @@ class MyLLM:
         try:
             self.conversation.add_message("user", prompt)
             response = await self.provider.create_async(
-                model=self.llm_model,
+                model=self.model,
                 messages=self.conversation.get_messages(),
             )
-            sleep(settings.lag)
+            sleep(self.lag)
             self.conversation.add_message("ai", response)
             return f"{settings.llm_prefix} {response}"
         except Exception as error:
             logger.error("No response from the model {}", error)
+            return error
 
     async def clear_chat_history(self):
         """
